@@ -170,7 +170,17 @@ class LogicBox(list):
         """ """
         with fieldwalker.value as field_value:
             for elem in field_value.iter_elements():
-                field_value.change_iter(lambda: iter([elem]))
+
+                def elem_iter():
+                    try:
+                        for e in elem:
+                            yield e
+                    except TypeError:
+                        pass
+                    finally:
+                        yield elem
+
+                field_value.change_iter(elem_iter)
                 if all(self._gen(fieldwalker)):
                     return True
 
@@ -704,10 +714,9 @@ def parse_elemMatch(query):
     def _elemMatch(fieldwalker):
         queryfilter = QueryFilter(query)
         doc_type = fieldwalker.doc_type
-        for value in fieldwalker.value.iter_arrays():
-            for v in value:
-                if queryfilter(v, doc_type):
-                    return True
+        for elem in fieldwalker.value.iter_elements():
+            if queryfilter(elem, doc_type):
+                return True
 
     return _elemMatch
 
